/* Generated by wayland-scanner 1.20.0 */

#ifndef WEBOS_FOREIGN_SERVER_PROTOCOL_H
#define WEBOS_FOREIGN_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_webos_foreign The webos_foreign protocol
 * @section page_ifaces_webos_foreign Interfaces
 * - @subpage page_iface_wl_webos_foreign - interface for handling foreign surfaces
 * - @subpage page_iface_wl_webos_exported - interface for handling exported window
 * - @subpage page_iface_wl_webos_imported - interface for imported content or punchthrough region
 * @section page_copyright_webos_foreign Copyright
 * <pre>
 *
 * Copyright (c) 2018-2019 LG Electronics, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * </pre>
 */
struct wl_region;
struct wl_surface;
struct wl_webos_exported;
struct wl_webos_foreign;
struct wl_webos_imported;

#ifndef WL_WEBOS_FOREIGN_INTERFACE
#define WL_WEBOS_FOREIGN_INTERFACE
/**
 * @page page_iface_wl_webos_foreign wl_webos_foreign
 * @section page_iface_wl_webos_foreign_desc Description
 *
 * This interface defines a way to associate one or more foreign surfaces from
 * different clients or a punch-through region to a surface that acts the main
 * window.
 *
 * You can set a region on the main window where a foreign surface or a
 * punch-through region can be placed. It is called "exported" region or window
 * in this protocol. Then you can request the compositor to punch through that
 * region or attach another surface as an "imported" content.
 * @section page_iface_wl_webos_foreign_api API
 * See @ref iface_wl_webos_foreign.
 */
/**
 * @defgroup iface_wl_webos_foreign The wl_webos_foreign interface
 *
 * This interface defines a way to associate one or more foreign surfaces from
 * different clients or a punch-through region to a surface that acts the main
 * window.
 *
 * You can set a region on the main window where a foreign surface or a
 * punch-through region can be placed. It is called "exported" region or window
 * in this protocol. Then you can request the compositor to punch through that
 * region or attach another surface as an "imported" content.
 */
extern const struct wl_interface wl_webos_foreign_interface;
#endif
#ifndef WL_WEBOS_EXPORTED_INTERFACE
#define WL_WEBOS_EXPORTED_INTERFACE
/**
 * @page page_iface_wl_webos_exported wl_webos_exported
 * @section page_iface_wl_webos_exported_desc Description
 *
 * This interface defines operations and notifications on an exported window.
 * @section page_iface_wl_webos_exported_api API
 * See @ref iface_wl_webos_exported.
 */
/**
 * @defgroup iface_wl_webos_exported The wl_webos_exported interface
 *
 * This interface defines operations and notifications on an exported window.
 */
extern const struct wl_interface wl_webos_exported_interface;
#endif
#ifndef WL_WEBOS_IMPORTED_INTERFACE
#define WL_WEBOS_IMPORTED_INTERFACE
/**
 * @page page_iface_wl_webos_imported wl_webos_imported
 * @section page_iface_wl_webos_imported_desc Description
 *
 * This interface defines operations and notifications on an imported object.
 * @section page_iface_wl_webos_imported_api API
 * See @ref iface_wl_webos_imported.
 */
/**
 * @defgroup iface_wl_webos_imported The wl_webos_imported interface
 *
 * This interface defines operations and notifications on an imported object.
 */
extern const struct wl_interface wl_webos_imported_interface;
#endif

#ifndef WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_ENUM
#define WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_ENUM
/**
 * @ingroup iface_wl_webos_foreign
 * type of webos_exported
 *
 * This indicates the type of the content that the exported window can show.
 */
enum wl_webos_foreign_webos_exported_type {
	/**
	 * exported window for video object
	 */
	WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_VIDEO_OBJECT = 0,
	/**
	 * exported window for subtitle object
	 */
	WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_SUBTITLE_OBJECT = 1,
	/**
	 * exported window for transparent object that does not need to punch through other windows
	 */
	WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_TRANSPARENT_OBJECT = 2,
	/**
	 * exported window for opaque object that always needs to punch through other windows
	 */
	WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_OPAQUE_OBJECT = 3,
};
#endif /* WL_WEBOS_FOREIGN_WEBOS_EXPORTED_TYPE_ENUM */

/**
 * @ingroup iface_wl_webos_foreign
 * @struct wl_webos_foreign_interface
 */
struct wl_webos_foreign_interface {
	/**
	 * destroy object
	 *
	 * Destroys the foreign object.
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * create webos_exported
	 *
	 * Requests to create an exported window on a given surface.
	 */
	void (*export_element)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t id,
			       struct wl_resource *surface,
			       uint32_t exported_type);
	/**
	 * create webos_imported
	 *
	 * Requests an import object that can be associated with a given
	 * exported window.
	 * @param window_id window_id of associated exported window assigned by compositor
	 */
	void (*import_element)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t id,
			       const char *window_id,
			       uint32_t exported_type);
};


/**
 * @ingroup iface_wl_webos_foreign
 */
#define WL_WEBOS_FOREIGN_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_foreign
 */
#define WL_WEBOS_FOREIGN_EXPORT_ELEMENT_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_foreign
 */
#define WL_WEBOS_FOREIGN_IMPORT_ELEMENT_SINCE_VERSION 1

/**
 * @ingroup iface_wl_webos_exported
 * @struct wl_webos_exported_interface
 */
struct wl_webos_exported_interface {
	/**
	 * destroy object
	 *
	 * Destroys the exported object.
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * set window to be exported
	 *
	 * Sets the exported window with source and destination regions.
	 * @param source_region source region of exported window
	 * @param destination_region destination region of exported window
	 */
	void (*set_exported_window)(struct wl_client *client,
				    struct wl_resource *resource,
				    struct wl_resource *source_region,
				    struct wl_resource *destination_region);
	/**
	 * set region to be cropped
	 *
	 * Sets a region to be cropped.
	 * @param original_input input resolution of original streaming
	 * @param source_region source region of exported window
	 * @param destination_region destination region of exported window
	 * @since 2
	 */
	void (*set_crop_region)(struct wl_client *client,
				struct wl_resource *resource,
				struct wl_resource *original_input,
				struct wl_resource *source_region,
				struct wl_resource *destination_region);
	/**
	 * set a property
	 *
	 * Sets a property for this webos_exported. The property is given
	 * by a string pair (name, value).
	 * @since 2
	 */
	void (*set_property)(struct wl_client *client,
			     struct wl_resource *resource,
			     const char *name,
			     const char *value);
};

#define WL_WEBOS_EXPORTED_WINDOW_ID_ASSIGNED 0

/**
 * @ingroup iface_wl_webos_exported
 */
#define WL_WEBOS_EXPORTED_WINDOW_ID_ASSIGNED_SINCE_VERSION 1

/**
 * @ingroup iface_wl_webos_exported
 */
#define WL_WEBOS_EXPORTED_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_exported
 */
#define WL_WEBOS_EXPORTED_SET_EXPORTED_WINDOW_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_exported
 */
#define WL_WEBOS_EXPORTED_SET_CROP_REGION_SINCE_VERSION 2
/**
 * @ingroup iface_wl_webos_exported
 */
#define WL_WEBOS_EXPORTED_SET_PROPERTY_SINCE_VERSION 2

/**
 * @ingroup iface_wl_webos_exported
 * Sends an window_id_assigned event to the client owning the resource.
 * @param resource_ The client's resource
 * @param window_id window_id of associated exported window
 */
static inline void
wl_webos_exported_send_window_id_assigned(struct wl_resource *resource_, const char *window_id, uint32_t exported_type)
{
	wl_resource_post_event(resource_, WL_WEBOS_EXPORTED_WINDOW_ID_ASSIGNED, window_id, exported_type);
}

#ifndef WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_ENUM
#define WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_ENUM
/**
 * @ingroup iface_wl_webos_imported
 * surface alignment
 *
 * The alignment of an imported surface on the associated exported window.
 */
enum wl_webos_imported_surface_alignment {
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_STRETCH = 0,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_NORTH = 1,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_WEST = 2,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_SOUTH = 4,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_EAST = 8,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_CENTER = 16,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_CROP = 32,
	WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_FIT = 64,
};
#endif /* WL_WEBOS_IMPORTED_SURFACE_ALIGNMENT_ENUM */

/**
 * @ingroup iface_wl_webos_imported
 * @struct wl_webos_imported_interface
 */
struct wl_webos_imported_interface {
	/**
	 * set surface alignment
	 *
	 * Sets the alignment of the imported surface.
	 * @param format alignment the texture onto export
	 */
	void (*set_surface_alignment)(struct wl_client *client,
				      struct wl_resource *resource,
				      uint32_t format);
	/**
	 * destroy object
	 *
	 * Destroys the imported object.
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * attach punchthrough
	 *
	 * Requests a punch-through on the exporetd window associated
	 * with this import object.
	 */
	void (*attach_punchthrough)(struct wl_client *client,
				    struct wl_resource *resource);
	/**
	 * set punchthrough to webos_imported
	 *
	 * 
	 * @param context_id context id for requesting to external entity
	 */
	void (*set_punchthrough)(struct wl_client *client,
				 struct wl_resource *resource,
				 const char *context_id);
	/**
	 * detach punchthrough
	 *
	 * Requests to detatch the punch-through from the exported window
	 * associated with this import object.
	 */
	void (*detach_punchthrough)(struct wl_client *client,
				    struct wl_resource *resource);
	/**
	 * attach surface
	 *
	 * Requests to attach the surface as imported to the associated
	 * exported window.
	 */
	void (*attach_surface)(struct wl_client *client,
			       struct wl_resource *resource,
			       struct wl_resource *surface);
	/**
	 * detach surface
	 *
	 * Requests to detach the surface as imported from the associated
	 * exported window.
	 */
	void (*detach_surface)(struct wl_client *client,
			       struct wl_resource *resource,
			       struct wl_resource *surface);
	/**
	 * attach punchthrough with context id
	 *
	 * Requests a punch-through on the exporetd window associated
	 * with this import object for a given context id.
	 * @param context_id context id for requesting to external entity
	 * @since 2
	 */
	void (*attach_punchthrough_with_context)(struct wl_client *client,
						 struct wl_resource *resource,
						 const char *context_id);
	/**
	 * set the z-index for webos_imported
	 *
	 * Set the z index for webos_imported. The compositor will move
	 * the surface, that is attached to webos_imported, to this layer.
	 * If no surface is attached to webos_imported, nothing will
	 * happen.
	 * @since 2
	 */
	void (*set_z_index)(struct wl_client *client,
			    struct wl_resource *resource,
			    int32_t z_index);
};

#define WL_WEBOS_IMPORTED_DESTINATION_REGION_CHANGED 0
#define WL_WEBOS_IMPORTED_PUNCHTHROUGH_ATTACHED 1
#define WL_WEBOS_IMPORTED_PUNCHTHROUGH_DETACHED 2
#define WL_WEBOS_IMPORTED_SURFACE_ATTACHED 3
#define WL_WEBOS_IMPORTED_SURFACE_DETACHED 4

/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_DESTINATION_REGION_CHANGED_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_PUNCHTHROUGH_ATTACHED_SINCE_VERSION 2
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_PUNCHTHROUGH_DETACHED_SINCE_VERSION 2
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_SURFACE_ATTACHED_SINCE_VERSION 2
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_SURFACE_DETACHED_SINCE_VERSION 2

/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_SET_SURFACE_ALIGNMENT_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_ATTACH_PUNCHTHROUGH_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_SET_PUNCHTHROUGH_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_DETACH_PUNCHTHROUGH_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_ATTACH_SURFACE_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_DETACH_SURFACE_SINCE_VERSION 1
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_ATTACH_PUNCHTHROUGH_WITH_CONTEXT_SINCE_VERSION 2
/**
 * @ingroup iface_wl_webos_imported
 */
#define WL_WEBOS_IMPORTED_SET_Z_INDEX_SINCE_VERSION 2

/**
 * @ingroup iface_wl_webos_imported
 * Sends an destination_region_changed event to the client owning the resource.
 * @param resource_ The client's resource
 * @param width destination width of exported window
 * @param height destination height of exported window
 */
static inline void
wl_webos_imported_send_destination_region_changed(struct wl_resource *resource_, uint32_t width, uint32_t height)
{
	wl_resource_post_event(resource_, WL_WEBOS_IMPORTED_DESTINATION_REGION_CHANGED, width, height);
}

/**
 * @ingroup iface_wl_webos_imported
 * Sends an punchthrough_attached event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
wl_webos_imported_send_punchthrough_attached(struct wl_resource *resource_, const char *context_id)
{
	wl_resource_post_event(resource_, WL_WEBOS_IMPORTED_PUNCHTHROUGH_ATTACHED, context_id);
}

/**
 * @ingroup iface_wl_webos_imported
 * Sends an punchthrough_detached event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
wl_webos_imported_send_punchthrough_detached(struct wl_resource *resource_, const char *context_id)
{
	wl_resource_post_event(resource_, WL_WEBOS_IMPORTED_PUNCHTHROUGH_DETACHED, context_id);
}

/**
 * @ingroup iface_wl_webos_imported
 * Sends an surface_attached event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
wl_webos_imported_send_surface_attached(struct wl_resource *resource_, struct wl_resource *surface)
{
	wl_resource_post_event(resource_, WL_WEBOS_IMPORTED_SURFACE_ATTACHED, surface);
}

/**
 * @ingroup iface_wl_webos_imported
 * Sends an surface_detached event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
wl_webos_imported_send_surface_detached(struct wl_resource *resource_, struct wl_resource *surface)
{
	wl_resource_post_event(resource_, WL_WEBOS_IMPORTED_SURFACE_DETACHED, surface);
}

#ifdef  __cplusplus
}
#endif

#endif
